"""
显示指定目录下的文件, 拼接 index.html 访问
"""

import os
import time

""" 扫描的目录 """
PATH = '/Users/mark/Downloads'



""" 指定一层目录 """
LEVEL = 1

def dirs_name():
    """  获取指定目录下的文件夹 """

    root_depth = len(PATH.split(os.path.sep))
    d = {}

    for root, dirs, files in os.walk(PATH, topdown=True):

        """ print dirs """
        for name in dirs:
            dir_path = os.path.join(root, name)
            dir_depth = len(dir_path.split(os.path.sep))
            if dir_depth == root_depth + LEVEL:
                d[name] = {}
                d[name]['name'] = name
                
                d[name]['time'] = time.strftime("%Y-%m-%d %H:%M:%S", (time.localtime(os.path.getmtime(dir_path))))
            
    return d

if __name__ == '__main__':
    dirs_name()
    # print(os.path.dirname(PATH))
    




from flask import Flask, request, render_template
import dirs_name
app = Flask(__name__)

app.debug = False

@app.route("/index", methods=["GET"])
def home():
    return render_template('home.html', dirs_name=dirs_name.dirs_name())



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="jmeterWebReport",
    version="0.0.4",
    author="mark",
    author_email="mamian521@gmail.com",
    license="Apache License",
    description="More convenient to show JMeter's web page report",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/magaofei/jmeterWebReport",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ),
)